# QuickStart

---
astrago sdk 쉽게 사용하기
1. astrago를 설치합니다.
```shell
pip install astrago
```

2. source code에 astrago를 추가합니다.
```python
import astrago

...
for i in range(10):
    astrago.log({'loss', ls, 'acc', acc})
```

3. Astrago에 접속 -> 비교실험에서 확인

# Tensorflow
Tensorflow를 활용한다면, callBack function을 활용하여 데이터를 수집할 수 있습니다.
